==> xld-sql-repository-10.2.0-531.743-sources.jar: com/xebialabs/deployit/artifact/resolution/InternalArtifactResolver.scala <==
package com.xebialabs.deployit.artifact.resolution

import java.io.InputStream
import java.net.URI
import java.util.concurrent.atomic.AtomicReference

import com.xebialabs.deployit.artifact.resolution.InternalArtifactResolver._
import com.xebialabs.deployit.engine.spi.artifact.resolution.ArtifactResolver.Resolver
import com.xebialabs.deployit.engine.spi.artifact.resolution.{ArtifactResolver, ResolvedArtifactFile}
import com.xebialabs.deployit.plugin.api.udm.artifact.SourceArtifact
import com.xebialabs.deployit.repository.sql.artifacts.ArtifactDataRepository
import org.springframework.beans.factory.annotation.Autowired

import scala.util.Try

@Resolver(protocols = Array(Protocol))
class InternalArtifactResolver extends ArtifactResolver {
  override def validateCorrectness(artifact: SourceArtifact): Boolean = canHandle(artifact.getFileUri)

  override def resolveLocation(artifact: SourceArtifact): ResolvedArtifactFile = new ResolvedArtifactFile {
    override def openStream(): InputStream = holder.get().retrieve(artifact.getId)
    override def getFileName: String = URI.create(artifact.getFileUri).getPath
    override def close(): Unit = {}
  }
}

object InternalArtifactResolver {

  final val Protocol = "internal"

  def canHandle(uri: String): Boolean = Try(URI.create(uri)).map(_.getScheme == Protocol).getOrElse(false)

  private final val holder = new AtomicReference[ArtifactDataRepository]()

  @Autowired
  def setArtifactRepository(artifactDataRepository: ArtifactDataRepository): Unit = {
    holder.getAndSet(artifactDataRepository)
  }

  def getInstance(): InternalArtifactResolver.type = this
}

==> xld-sql-repository-22.1.12-sources.jar: com/xebialabs/deployit/artifact/resolution/InternalArtifactResolver.scala <==
package com.xebialabs.deployit.artifact.resolution

import java.io.InputStream
import java.net.{URI, URLEncoder}
import java.util.concurrent.atomic.AtomicReference

import com.xebialabs.deployit.artifact.resolution.InternalArtifactResolver._
import com.xebialabs.deployit.engine.spi.artifact.resolution.ArtifactResolver.Resolver
import com.xebialabs.deployit.engine.spi.artifact.resolution.{ArtifactResolver, ResolvedArtifactFile}
import com.xebialabs.deployit.plugin.api.udm.artifact.SourceArtifact
import com.xebialabs.deployit.repository.sql.artifacts.ArtifactDataRepository
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.context.annotation.Lazy

import scala.util.Try

@Resolver(protocols = Array(Protocol))
class InternalArtifactResolver extends ArtifactResolver {
  override def validateCorrectness(artifact: SourceArtifact): Boolean = canHandle(artifact.getFileUri)

  override def resolveLocation(artifact: SourceArtifact): ResolvedArtifactFile = new ResolvedArtifactFile {
    override def openStream(): InputStream = holder.get().retrieve(artifact.getId)
    override def getFileName: String = URI.create(URLEncoder.encode(artifact.getFileUri, "UTF-8")).getPath
    override def close(): Unit = {}
  }
}

object InternalArtifactResolver {

  final val Protocol = "internal"

  def canHandle(uri: String): Boolean = Try(URI.create(uri)).map(_.getScheme == Protocol).getOrElse(false)

  private final val holder = new AtomicReference[ArtifactDataRepository]()

  @Lazy
  @Autowired
  def setArtifactRepository(artifactDataRepository: ArtifactDataRepository): Unit = {
    holder.getAndSet(artifactDataRepository)
  }

  def getInstance(): InternalArtifactResolver.type = this
}
